function [xdot] = Electrophilic_stress_response(varargin)
%
% Electrophilic_stress_response
% Generated: 10/20/06 17:43:34
%
% [xdot] = Electrophilic_stress_response() => xdot = initial conditions in column vector
% [xdot] = Electrophilic_stress_response('states') => xdot = species names in cell-array
% [xdot] = Electrophilic_stress_response('parameters') => xdot = parameter names in cell-array
% [xdot] = Electrophilic_stress_response('parametervalues') => xdot = parameter values in column vector
% [xdot] = Electrophilic_stress_response(t,x) => xdot = time derivatives in column vector
% [xdot] = Electrophilic_stress_response(t,x,PARAMETERS,PARAMETERVALUES) => xdot = time
%       derivatives in column vector. PARAMETERS is a cell-array of strings
%       containing the parameters which will have changed values,
%       PARAMETERVALUES is a vector of parametervalues for the parameters
%       to be changed.
%
% State names and ordering:
%
% x(1): stressor
% x(2): Cytosol_GST_mRNA
% x(3): Cytosol_sink
% x(4): Cytosol_GSTmono
% x(5): Cytosol_Nrf2_mRNA
% x(6): Cytosol_GST
% x(7): Cytosol_X
% x(8): Cytosol_GSH
% x(9): Cytosol_GSX
% x(10): Cytosol_GSmono
% x(11): Cytosol_GS
% x(12): Cytosol_nucleus_GSTon
% x(13): Cytosol_nucleus_EpRE_GST_
% x(14): Cytosol_nucleus_Nrf2_Maf
% x(15): Cytosol_nucleus_Nrf2_Maf__EpRE_GST_
% x(16): Cytosol_nucleus_GSToff
% x(17): Cytosol_nucleus_MRPon
% x(18): Cytosol_MRP_mRNA
% x(19): Cytosol_nucleus_EpRE_MRP_
% x(20): Cytosol_nucleus_Nrf2_Maf__EpRE_MRP_
% x(21): Cytosol_nucleus_MRPoff
% x(22): Cytosol_nucleus_GCLMon
% x(23): Cytosol_nucleus_Maf
% x(24): Cytosol_nucleus_Nrf2
% x(25): Cytosol_nucleus_EpRE_GCLM_
% x(26): Cytosol_nucleus_GSoff
% x(27): Cytosol_nucleus_GCLCoff
% x(28): Cytosol_nucleus_Nrf2_Maf__EpRE_GCLC_
% x(29): Cytosol_nucleus_Nrf2_Maf__EpRE_GS_
% x(30): Cytosol_nucleus_Nrf2off
% x(31): Cytosol_nucleus_EpRE_GS_
% x(32): Cytosol_nucleus_GCLCon
% x(33): Cytosol_GCLC_mRNA
% x(34): Cytosol_nucleus_Nrf2on
% x(35): Cytosol_nucleus_EpRE_Nrf2_
% x(36): Cytosol_nucleus_Nrf2_Maf__EpRE_Nrf2_
% x(37): Cytosol_nucleus_sink
% x(38): Cytosol_nucleus_GSon
% x(39): Cytosol_nucleus_EpRE_GCLC_
% x(40): Cytosol_nucleus_Nrf2_Maf__EpRE_GCLM_
% x(41): Cytosol_Nrf2
% x(42): Cytosol_GS_mRNA
% x(43): Cytosol_GCLM_mRNA
% x(44): Cytosol_nucleus_GCLMoff
% x(45): Cytosol_GCLC
% x(46): Cytosol_r_GC
% x(47): Cytosol_MRPmono
% x(48): Cytosol_MRP
% x(49): Cytosol_Keap1
% x(50): Cytosol_GCLM
% x(51): Cytosol_GCL
% x(52): Cytosol_Nrf2_Keap1
% x(53): Cytosol_Keap1o
% x(54): Cytosol_Nrf2_Keap1o
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% HANDLE VARIABLE ARGUMENTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nargin == 0,
    % Return initial conditions of the state variables
    xdot = [
        0 ; 0.4656 ; 0 ; 121 ; 0.027
        146 ; 1000 ; 5000000 ; 200 ; 300
        1000 ; 0 ; 0.0167 ; 0 ; 0
        0.0167 ; 0 ; 4.234 ; 0.0167 ; 0
        0.0167 ; 0 ; 1 ; 1 ; 0.0167
        0.0167 ; 0.0167 ; 0 ; 0 ; 0.0167
        0.0167 ; 0 ; 2.125 ; 0 ; 0.0167
        0 ; 0 ; 0 ; 0.0167 ; 0
        0.5 ; 1.176 ; 0.8884 ; 0.0167 ; 1633
        150000 ; 3800 ; 7220 ; 20 ; 403
        656 ; 0 ; 0 ; 0
    ];
    return
elseif nargin == 1,
    if strcmp(varargin{1}, 'states'),
        % Return state names in cell-array
        xdot = {
            'stressor' ; 'Cytosol_GST_mRNA' ; 'Cytosol_sink' ; 'Cytosol_GSTmono' ; 'Cytosol_Nrf2_mRNA'
            'Cytosol_GST' ; 'Cytosol_X' ; 'Cytosol_GSH' ; 'Cytosol_GSX' ; 'Cytosol_GSmono'
            'Cytosol_GS' ; 'Cytosol_nucleus_GSTon' ; 'Cytosol_nucleus_EpRE_GST_' ; 'Cytosol_nucleus_Nrf2_Maf' ; 'Cytosol_nucleus_Nrf2_Maf__EpRE_GST_'
            'Cytosol_nucleus_GSToff' ; 'Cytosol_nucleus_MRPon' ; 'Cytosol_MRP_mRNA' ; 'Cytosol_nucleus_EpRE_MRP_' ; 'Cytosol_nucleus_Nrf2_Maf__EpRE_MRP_'
            'Cytosol_nucleus_MRPoff' ; 'Cytosol_nucleus_GCLMon' ; 'Cytosol_nucleus_Maf' ; 'Cytosol_nucleus_Nrf2' ; 'Cytosol_nucleus_EpRE_GCLM_'
            'Cytosol_nucleus_GSoff' ; 'Cytosol_nucleus_GCLCoff' ; 'Cytosol_nucleus_Nrf2_Maf__EpRE_GCLC_' ; 'Cytosol_nucleus_Nrf2_Maf__EpRE_GS_' ; 'Cytosol_nucleus_Nrf2off'
            'Cytosol_nucleus_EpRE_GS_' ; 'Cytosol_nucleus_GCLCon' ; 'Cytosol_GCLC_mRNA' ; 'Cytosol_nucleus_Nrf2on' ; 'Cytosol_nucleus_EpRE_Nrf2_'
            'Cytosol_nucleus_Nrf2_Maf__EpRE_Nrf2_' ; 'Cytosol_nucleus_sink' ; 'Cytosol_nucleus_GSon' ; 'Cytosol_nucleus_EpRE_GCLC_' ; 'Cytosol_nucleus_Nrf2_Maf__EpRE_GCLM_'
            'Cytosol_Nrf2' ; 'Cytosol_GS_mRNA' ; 'Cytosol_GCLM_mRNA' ; 'Cytosol_nucleus_GCLMoff' ; 'Cytosol_GCLC'
            'Cytosol_r_GC' ; 'Cytosol_MRPmono' ; 'Cytosol_MRP' ; 'Cytosol_Keap1' ; 'Cytosol_GCLM'
            'Cytosol_GCL' ; 'Cytosol_Nrf2_Keap1' ; 'Cytosol_Keap1o' ; 'Cytosol_Nrf2_Keap1o'
        };
    elseif strcmp(varargin{1}, 'parameters'),
        xdot = {
            'Cytosol_trans_GST_4_kf' ; 'Cytosol_trans_GST_5_kf' ; 'Cytosol_enzyme_GST_kc' ; 'Cytosol_enzyme_GST_Km_GSH' ; 'Cytosol_enzyme_GST_Km_X'
            'Cytosol_enzyme_GST_Ki' ; 'Cytosol_reaction_GS_dimerize_kf' ; 'Cytosol_reaction_GS_dimerize_kb' ; 'Cytosol_trans_GST_6_kf' ; 'Cytosol_reaction_GST_dimerize_kf'
            'Cytosol_reaction_GST_dimerize_kb' ; 'Cytosol_trans_GST_7_kf' ; 'Cytosol_nucleus_trans_GST_3_kf' ; 'Cytosol_nucleus_trans_GST_1_kf' ; 'Cytosol_nucleus_trans_GST_1_kb'
            'Cytosol_nucleus_trans_GST_1_n' ; 'Cytosol_nucleus_trans_GST_1_k' ; 'Cytosol_nucleus_trans_GST_2_kf' ; 'Cytosol_nucleus_trans_GST_2_kb' ; 'Cytosol_nucleus_trans_GST_2_k0'
            'Cytosol_nucleus_trans_MRP_3_kf' ; 'Cytosol_nucleus_trans_MRP_1_kf' ; 'Cytosol_nucleus_trans_MRP_1_kb' ; 'Cytosol_nucleus_trans_MRP_1_n' ; 'Cytosol_nucleus_trans_MRP_1_k'
            'Cytosol_nucleus_trans_MRP_2_kf' ; 'Cytosol_nucleus_trans_MRP_2_kb' ; 'Cytosol_nucleus_trans_MRP_2_k0' ; 'Cytosol_nucleus_reaction_Nrf2_Maf_kf' ; 'Cytosol_nucleus_reaction_Nrf2_Maf_kb'
            'Cytosol_nucleus_trans_GCLC_3_kf' ; 'Cytosol_nucleus_trans_Nrf2_1_kf' ; 'Cytosol_nucleus_trans_Nrf2_1_kb' ; 'Cytosol_nucleus_reaction_Nrf2_nuclear_degradation_kf' ; 'Cytosol_nucleus_trans_GS_2_kf'
            'Cytosol_nucleus_trans_GS_2_kb' ; 'Cytosol_nucleus_trans_GS_2_k0' ; 'Cytosol_nucleus_trans_GCLC_1_kf' ; 'Cytosol_nucleus_trans_GCLC_1_kb' ; 'Cytosol_nucleus_trans_GCLC_1_n'
            'Cytosol_nucleus_trans_GCLC_1_k' ; 'Cytosol_nucleus_trans_Nrf2_3_kf' ; 'Cytosol_nucleus_trans_GCLM_1_kf' ; 'Cytosol_nucleus_trans_GCLM_1_kb' ; 'Cytosol_nucleus_trans_GCLM_1_n'
            'Cytosol_nucleus_trans_GCLM_1_k' ; 'Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle_kf' ; 'Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle_kb' ; 'Cytosol_nucleus_trans_GCLC_2_kf' ; 'Cytosol_nucleus_trans_GCLC_2_kb'
            'Cytosol_nucleus_trans_GCLC_2_k0' ; 'Cytosol_nucleus_trans_GS_3_kf' ; 'Cytosol_nucleus_trans_GS_1_kf' ; 'Cytosol_nucleus_trans_GS_1_kb' ; 'Cytosol_nucleus_trans_GS_1_n'
            'Cytosol_nucleus_trans_GS_1_k' ; 'Cytosol_nucleus_trans_GCLM_3_kf' ; 'Cytosol_nucleus_trans_GCLM_2_kf' ; 'Cytosol_nucleus_trans_GCLM_2_kb' ; 'Cytosol_nucleus_trans_GCLM_2_k0'
            'Cytosol_nucleus_trans_Nrf2_2_kf' ; 'Cytosol_nucleus_trans_Nrf2_2_kb' ; 'Cytosol_nucleus_trans_Nrf2_2_k0' ; 'Cytosol_trans_Nrf2_5_kf' ; 'Cytosol_trans_GS_7_kf'
            'Cytosol_trans_MRP_5_kf' ; 'Cytosol_trans_MRP_4_kf' ; 'Cytosol_trans_MRP_6_kf' ; 'Cytosol_reaction_MRP_dimerize_kf' ; 'Cytosol_reaction_MRP_dimerize_kb'
            'Cytosol_trans_MRP_7_kf' ; 'Cytosol_reaction_GSH_export_Vm' ; 'Cytosol_reaction_GSH_export_Km' ; 'Cytosol_reaction_X_generation_from_stressor_kf' ; 'Cytosol_reaction_GCL_dimerize_kf'
            'Cytosol_reaction_GCL_dimerize_kb' ; 'Cytosol_GSX_export_kc' ; 'Cytosol_GSX_export_Km' ; 'Cytosol_reaction_Keap1_1_kf' ; 'Cytosol_reaction_Keap1_1_kb'
            'Cytosol_trans_GCLC_5_kf' ; 'Cytosol_trans_GCLM_6_kf' ; 'Cytosol_trans_Nrf2_6_kf' ; 'Cytosol_enzyme_GCL_kc_GCL' ; 'Cytosol_enzyme_GCL_Km_GCL_Glu'
            'Cytosol_enzyme_GCL_Kis_GCL_Glu' ; 'Cytosol_enzyme_GCL_Kii_GCL_Glu' ; 'Cytosol_enzyme_GCL_Km_GCL_ATP' ; 'Cytosol_enzyme_GCL_Kis_GCL_ATP' ; 'Cytosol_enzyme_GCL_Kii_GCL_ATP'
            'Cytosol_enzyme_GCL_Km_GCL_Cys' ; 'Cytosol_enzyme_GCL_kc_GCLC' ; 'Cytosol_enzyme_GCL_Km_GCLC_Glu' ; 'Cytosol_enzyme_GCL_Kis_GCLC_Glu' ; 'Cytosol_enzyme_GCL_Kii_GCLC_Glu'
            'Cytosol_enzyme_GCL_Km_GCLC_ATP' ; 'Cytosol_enzyme_GCL_Kis_GCLC_ATP' ; 'Cytosol_enzyme_GCL_Kii_GCLC_ATP' ; 'Cytosol_enzyme_GCL_Km_GCLC_Cys' ; 'Cytosol_enzyme_GCL_n'
            'Cytosol_trans_GCLC_6_kf' ; 'Cytosol_trans_GS_6_kf' ; 'Cytosol_reaction_Keap1_6_kf' ; 'Cytosol_reaction_Keap1_6_kb' ; 'Cytosol_reaction_X_endo_production_kf'
            'Cytosol_trans_GS_4_kf' ; 'Cytosol_trans_GCLM_5_kf' ; 'Cytosol_trans_Nrf2_4_kf' ; 'Cytosol_reaction_Keap1_2_kf' ; 'Cytosol_reaction_GCL_degrade_kf'
            'Cytosol_reaction_Keap1_3f_k0' ; 'Cytosol_reaction_Keap1_3f_kf_X' ; 'Cytosol_trans_GS_5_kf' ; 'Cytosol_trans_GCLC_4_kf' ; 'Cytosol_reaction_Keap1_3b_kf'
            'Cytosol_reaction_Keap1_4f_k0' ; 'Cytosol_reaction_Keap1_4f_kf_X' ; 'Cytosol_reaction_Keap1_5_kf' ; 'Cytosol_enzyme_GS_kc' ; 'Cytosol_enzyme_GS_Km1_rGC'
            'Cytosol_enzyme_GS_Km2_rGC' ; 'Cytosol_enzyme_GS_Km_Gly' ; 'Cytosol_enzyme_GS_Km_ATP' ; 'Cytosol_trans_GCLM_4_kf' ; 'Cytosol_reaction_Keap1_4b_kf'
        };
    elseif strcmp(varargin{1}, 'parametervalues'),
        xdot = [
            4.71e-005 ; 0.0417 ; 7.67 ; 500000 ; 50000
            85000 ; 0.0002 ; 0.02 ; 0.000129 ; 0.0002
            0.02 ; 1.29e-005 ; 0.242 ; 0.002 ; 0.02
            2 ; 21 ; 11.9 ; 0.01 ; 0.001
            0.9 ; 0.002 ; 0.02 ; 2 ; 21
            16 ; 0.01 ; 0.0006800000000000001 ; 0.001 ; 0.02
            1.2 ; 0.002 ; 0.02 ; 0.0001 ; 5.95
            0.01 ; 0.0005000000000000001 ; 0.002 ; 0.02 ; 3
            400 ; 0.00611 ; 0.002 ; 0.02 ; 3
            400 ; 2 ; 1 ; 8.699999999999999 ; 0.01
            0.0004 ; 1.15 ; 0.002 ; 0.02 ; 2
            21 ; 3.22 ; 1.6 ; 0.01 ; 0.00013
            100 ; 0.01 ; 0.002500000000000001 ; 0.0417 ; 1.93e-005
            0.0417 ; 1.93e-005 ; 1.93e-005 ; 1e-005 ; 0.02
            7.15e-006 ; 1845 ; 20000000 ; 20 ; 2e-005
            0.02 ; 0.1 ; 7000 ; 0.002 ; 0.02
            0.0417 ; 3.86e-005 ; 0.0001 ; 8.199999999999999 ; 480000
            800000 ; 3100000 ; 870000 ; 6500000 ; 3900000
            220000 ; 1.9 ; 1600000 ; 300000 ; 800000
            5000000 ; 1300000 ; 400000 ; 270000 ; 1
            3.86e-005 ; 3.86e-005 ; 0.002 ; 0.02 ; 20
            4.83e-005 ; 0.0417 ; 6.43e-005 ; 0.014 ; 3.86e-005
            0.9300000000000001 ; 0.00026 ; 0.0417 ; 4.83e-005 ; 0.1
            0.9300000000000001 ; 0.00026 ; 0.0001 ; 6.5 ; 660000
            1500000 ; 1750000 ; 70000 ; 4.83e-005 ; 0.1
        ];
    else
        error('Wrong input arguments! Please read the help text to the ODE file.');
    end
    return
elseif (nargin == 2) | (nargin == 3),
    t = varargin{1};
    x = varargin{2};
    PARAMETERS = [];
    PARAMETERVALUES = [];
elseif nargin == 4,
    t = varargin{1};
    x = varargin{2};
    PARAMETERS = varargin{3};
    if strcmp(class(PARAMETERS),'char'),
        PARAMETERS = {PARAMETERS};
    end
    PARAMETERVALUES = varargin{4};
    if length(PARAMETERS) ~= length(PARAMETERVALUES),
        error('Not the same number of PARAMETERS and PARAMETERVALUES have been supplied!');
    end
else
    error('Wrong input arguments! Please read the help text to the ODE file.');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STATES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
stressor = x(1);
Cytosol_GST_mRNA = x(2);
Cytosol_GSTmono = x(4);
Cytosol_Nrf2_mRNA = x(5);
Cytosol_GST = x(6);
Cytosol_X = x(7);
Cytosol_GSH = x(8);
Cytosol_GSX = x(9);
Cytosol_GSmono = x(10);
Cytosol_GS = x(11);
Cytosol_nucleus_GSTon = x(12);
Cytosol_nucleus_EpRE_GST_ = x(13);
Cytosol_nucleus_Nrf2_Maf = x(14);
Cytosol_nucleus_Nrf2_Maf__EpRE_GST_ = x(15);
Cytosol_nucleus_GSToff = x(16);
Cytosol_nucleus_MRPon = x(17);
Cytosol_MRP_mRNA = x(18);
Cytosol_nucleus_EpRE_MRP_ = x(19);
Cytosol_nucleus_Nrf2_Maf__EpRE_MRP_ = x(20);
Cytosol_nucleus_MRPoff = x(21);
Cytosol_nucleus_GCLMon = x(22);
Cytosol_nucleus_Maf = x(23);
Cytosol_nucleus_Nrf2 = x(24);
Cytosol_nucleus_EpRE_GCLM_ = x(25);
Cytosol_nucleus_GSoff = x(26);
Cytosol_nucleus_GCLCoff = x(27);
Cytosol_nucleus_Nrf2_Maf__EpRE_GCLC_ = x(28);
Cytosol_nucleus_Nrf2_Maf__EpRE_GS_ = x(29);
Cytosol_nucleus_Nrf2off = x(30);
Cytosol_nucleus_EpRE_GS_ = x(31);
Cytosol_nucleus_GCLCon = x(32);
Cytosol_GCLC_mRNA = x(33);
Cytosol_nucleus_Nrf2on = x(34);
Cytosol_nucleus_EpRE_Nrf2_ = x(35);
Cytosol_nucleus_Nrf2_Maf__EpRE_Nrf2_ = x(36);
Cytosol_nucleus_GSon = x(38);
Cytosol_nucleus_EpRE_GCLC_ = x(39);
Cytosol_nucleus_Nrf2_Maf__EpRE_GCLM_ = x(40);
Cytosol_Nrf2 = x(41);
Cytosol_GS_mRNA = x(42);
Cytosol_GCLM_mRNA = x(43);
Cytosol_nucleus_GCLMoff = x(44);
Cytosol_GCLC = x(45);
Cytosol_r_GC = x(46);
Cytosol_MRPmono = x(47);
Cytosol_MRP = x(48);
Cytosol_Keap1 = x(49);
Cytosol_GCLM = x(50);
Cytosol_GCL = x(51);
Cytosol_Nrf2_Keap1 = x(52);
Cytosol_Keap1o = x(53);
Cytosol_Nrf2_Keap1o = x(54);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PARAMETERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Cytosol_trans_GST_4_kf = 4.71e-005;
Cytosol_trans_GST_5_kf = 0.0417;
Cytosol_enzyme_GST_kc = 7.67;
Cytosol_enzyme_GST_Km_GSH = 500000;
Cytosol_enzyme_GST_Km_X = 50000;
Cytosol_enzyme_GST_Ki = 85000;
Cytosol_reaction_GS_dimerize_kf = 0.0002;
Cytosol_reaction_GS_dimerize_kb = 0.02;
Cytosol_trans_GST_6_kf = 0.000129;
Cytosol_reaction_GST_dimerize_kf = 0.0002;
Cytosol_reaction_GST_dimerize_kb = 0.02;
Cytosol_trans_GST_7_kf = 1.29e-005;
Cytosol_nucleus_trans_GST_3_kf = 0.242;
Cytosol_nucleus_trans_GST_1_kf = 0.002;
Cytosol_nucleus_trans_GST_1_kb = 0.02;
Cytosol_nucleus_trans_GST_1_n = 2;
Cytosol_nucleus_trans_GST_1_k = 21;
Cytosol_nucleus_trans_GST_2_kf = 11.9;
Cytosol_nucleus_trans_GST_2_kb = 0.01;
Cytosol_nucleus_trans_GST_2_k0 = 0.001;
Cytosol_nucleus_trans_MRP_3_kf = 0.9;
Cytosol_nucleus_trans_MRP_1_kf = 0.002;
Cytosol_nucleus_trans_MRP_1_kb = 0.02;
Cytosol_nucleus_trans_MRP_1_n = 2;
Cytosol_nucleus_trans_MRP_1_k = 21;
Cytosol_nucleus_trans_MRP_2_kf = 16;
Cytosol_nucleus_trans_MRP_2_kb = 0.01;
Cytosol_nucleus_trans_MRP_2_k0 = 0.0006800000000000001;
Cytosol_nucleus_reaction_Nrf2_Maf_kf = 0.001;
Cytosol_nucleus_reaction_Nrf2_Maf_kb = 0.02;
Cytosol_nucleus_trans_GCLC_3_kf = 1.2;
Cytosol_nucleus_trans_Nrf2_1_kf = 0.002;
Cytosol_nucleus_trans_Nrf2_1_kb = 0.02;
Cytosol_nucleus_reaction_Nrf2_nuclear_degradation_kf = 0.0001;
Cytosol_nucleus_trans_GS_2_kf = 5.95;
Cytosol_nucleus_trans_GS_2_kb = 0.01;
Cytosol_nucleus_trans_GS_2_k0 = 0.0005000000000000001;
Cytosol_nucleus_trans_GCLC_1_kf = 0.002;
Cytosol_nucleus_trans_GCLC_1_kb = 0.02;
Cytosol_nucleus_trans_GCLC_1_n = 3;
Cytosol_nucleus_trans_GCLC_1_k = 400;
Cytosol_nucleus_trans_Nrf2_3_kf = 0.00611;
Cytosol_nucleus_trans_GCLM_1_kf = 0.002;
Cytosol_nucleus_trans_GCLM_1_kb = 0.02;
Cytosol_nucleus_trans_GCLM_1_n = 3;
Cytosol_nucleus_trans_GCLM_1_k = 400;
Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle_kf = 2;
Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle_kb = 1;
Cytosol_nucleus_trans_GCLC_2_kf = 8.699999999999999;
Cytosol_nucleus_trans_GCLC_2_kb = 0.01;
Cytosol_nucleus_trans_GCLC_2_k0 = 0.0004;
Cytosol_nucleus_trans_GS_3_kf = 1.15;
Cytosol_nucleus_trans_GS_1_kf = 0.002;
Cytosol_nucleus_trans_GS_1_kb = 0.02;
Cytosol_nucleus_trans_GS_1_n = 2;
Cytosol_nucleus_trans_GS_1_k = 21;
Cytosol_nucleus_trans_GCLM_3_kf = 3.22;
Cytosol_nucleus_trans_GCLM_2_kf = 1.6;
Cytosol_nucleus_trans_GCLM_2_kb = 0.01;
Cytosol_nucleus_trans_GCLM_2_k0 = 0.00013;
Cytosol_nucleus_trans_Nrf2_2_kf = 100;
Cytosol_nucleus_trans_Nrf2_2_kb = 0.01;
Cytosol_nucleus_trans_Nrf2_2_k0 = 0.002500000000000001;
Cytosol_trans_Nrf2_5_kf = 0.0417;
Cytosol_trans_GS_7_kf = 1.93e-005;
Cytosol_trans_MRP_5_kf = 0.0417;
Cytosol_trans_MRP_4_kf = 1.93e-005;
Cytosol_trans_MRP_6_kf = 1.93e-005;
Cytosol_reaction_MRP_dimerize_kf = 1e-005;
Cytosol_reaction_MRP_dimerize_kb = 0.02;
Cytosol_trans_MRP_7_kf = 7.15e-006;
Cytosol_reaction_GSH_export_Vm = 1845;
Cytosol_reaction_GSH_export_Km = 20000000;
Cytosol_reaction_X_generation_from_stressor_kf = 20;
Cytosol_reaction_GCL_dimerize_kf = 2e-005;
Cytosol_reaction_GCL_dimerize_kb = 0.02;
Cytosol_GSX_export_kc = 0.1;
Cytosol_GSX_export_Km = 7000;
Cytosol_reaction_Keap1_1_kf = 0.002;
Cytosol_reaction_Keap1_1_kb = 0.02;
Cytosol_trans_GCLC_5_kf = 0.0417;
Cytosol_trans_GCLM_6_kf = 3.86e-005;
Cytosol_trans_Nrf2_6_kf = 0.0001;
Cytosol_enzyme_GCL_kc_GCL = 8.199999999999999;
Cytosol_enzyme_GCL_Km_GCL_Glu = 480000;
Cytosol_enzyme_GCL_Kis_GCL_Glu = 800000;
Cytosol_enzyme_GCL_Kii_GCL_Glu = 3100000;
Cytosol_enzyme_GCL_Km_GCL_ATP = 870000;
Cytosol_enzyme_GCL_Kis_GCL_ATP = 6500000;
Cytosol_enzyme_GCL_Kii_GCL_ATP = 3900000;
Cytosol_enzyme_GCL_Km_GCL_Cys = 220000;
Cytosol_enzyme_GCL_kc_GCLC = 1.9;
Cytosol_enzyme_GCL_Km_GCLC_Glu = 1600000;
Cytosol_enzyme_GCL_Kis_GCLC_Glu = 300000;
Cytosol_enzyme_GCL_Kii_GCLC_Glu = 800000;
Cytosol_enzyme_GCL_Km_GCLC_ATP = 5000000;
Cytosol_enzyme_GCL_Kis_GCLC_ATP = 1300000;
Cytosol_enzyme_GCL_Kii_GCLC_ATP = 400000;
Cytosol_enzyme_GCL_Km_GCLC_Cys = 270000;
Cytosol_enzyme_GCL_n = 1;
Cytosol_trans_GCLC_6_kf = 3.86e-005;
Cytosol_trans_GS_6_kf = 3.86e-005;
Cytosol_reaction_Keap1_6_kf = 0.002;
Cytosol_reaction_Keap1_6_kb = 0.02;
Cytosol_reaction_X_endo_production_kf = 20;
Cytosol_trans_GS_4_kf = 4.83e-005;
Cytosol_trans_GCLM_5_kf = 0.0417;
Cytosol_trans_Nrf2_4_kf = 6.43e-005;
Cytosol_reaction_Keap1_2_kf = 0.014;
Cytosol_reaction_GCL_degrade_kf = 3.86e-005;
Cytosol_reaction_Keap1_3f_k0 = 0.9300000000000001;
Cytosol_reaction_Keap1_3f_kf_X = 0.00026;
Cytosol_trans_GS_5_kf = 0.0417;
Cytosol_trans_GCLC_4_kf = 4.83e-005;
Cytosol_reaction_Keap1_3b_kf = 0.1;
Cytosol_reaction_Keap1_4f_k0 = 0.9300000000000001;
Cytosol_reaction_Keap1_4f_kf_X = 0.00026;
Cytosol_reaction_Keap1_5_kf = 0.0001;
Cytosol_enzyme_GS_kc = 6.5;
Cytosol_enzyme_GS_Km1_rGC = 660000;
Cytosol_enzyme_GS_Km2_rGC = 1500000;
Cytosol_enzyme_GS_Km_Gly = 1750000;
Cytosol_enzyme_GS_Km_ATP = 70000;
Cytosol_trans_GCLM_4_kf = 4.83e-005;
Cytosol_reaction_Keap1_4b_kf = 0.1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ADJUST PARAMETERS IF NEEDED
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for k = 1:length(PARAMETERS),
    eval(sprintf('%s = %f;', PARAMETERS{k},PARAMETERVALUES(k)));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% AUXILIARY VARIABLES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Medium = 1e7;
Cytosol = 1000;
Cytosol_nucleus = 100;
Cytosol_trans_GST_4 = Cytosol_trans_GST_4_kf * Cytosol_GST_mRNA;
Cytosol_trans_GST_5 = Cytosol_trans_GST_5_kf * Cytosol_GST_mRNA;
Cytosol_enzyme_GST_v_GSH = Cytosol_GSH / (Cytosol_enzyme_GST_Km_GSH * (1 + Cytosol_GSX / Cytosol_enzyme_GST_Ki) + Cytosol_GSH);
Cytosol_enzyme_GST_v_X = Cytosol_X / ((Cytosol_enzyme_GST_Km_X + Cytosol_X) * (1 + Cytosol_GSX / Cytosol_enzyme_GST_Ki));
Cytosol_enzyme_GST = (((Cytosol_enzyme_GST_kc * Cytosol_GST) * Cytosol_enzyme_GST_v_GSH) * Cytosol_enzyme_GST_v_X) * 1 + ((0 * Cytosol_GSH) * Cytosol_X) * 0.404e-8;
Cytosol_reaction_GS_dimerize = (Cytosol_reaction_GS_dimerize_kf * Cytosol_GSmono) * Cytosol_GSmono - Cytosol_reaction_GS_dimerize_kb * Cytosol_GS;
Cytosol_trans_GST_6 = Cytosol_trans_GST_6_kf * Cytosol_GSTmono;
Cytosol_reaction_GST_dimerize = (Cytosol_reaction_GST_dimerize_kf * Cytosol_GSTmono) * Cytosol_GSTmono - Cytosol_reaction_GST_dimerize_kb * Cytosol_GST;
Cytosol_trans_GST_7 = Cytosol_trans_GST_7_kf * Cytosol_GST;
Cytosol_nucleus_trans_GST_3_b = 1 / 3;
Cytosol_nucleus_trans_GST_3 = (Cytosol_nucleus_trans_GST_3_kf * Cytosol_nucleus_GSTon) * Cytosol_nucleus_trans_GST_3_b;
Cytosol_nucleus_trans_GST_1 = ((Cytosol_nucleus_trans_GST_1_k * Cytosol_nucleus_trans_GST_1_kf) * Cytosol_nucleus_EpRE_GST_) * Cytosol_nucleus_Nrf2_Maf ^ Cytosol_nucleus_trans_GST_1_n - Cytosol_nucleus_trans_GST_1_kb * Cytosol_nucleus_Nrf2_Maf__EpRE_GST_;
Cytosol_nucleus_trans_GST_2 = (Cytosol_nucleus_trans_GST_2_k0 * Cytosol_nucleus_GSToff + (Cytosol_nucleus_trans_GST_2_kf * Cytosol_nucleus_GSToff) * Cytosol_nucleus_Nrf2_Maf__EpRE_GST_) - Cytosol_nucleus_trans_GST_2_kb * Cytosol_nucleus_GSTon;
Cytosol_nucleus_trans_MRP_3_b = 1 / 3;
Cytosol_nucleus_trans_MRP_3 = (Cytosol_nucleus_trans_MRP_3_kf * Cytosol_nucleus_MRPon) * Cytosol_nucleus_trans_MRP_3_b;
Cytosol_nucleus_trans_MRP_1 = ((Cytosol_nucleus_trans_MRP_1_k * Cytosol_nucleus_trans_MRP_1_kf) * Cytosol_nucleus_EpRE_MRP_) * Cytosol_nucleus_Nrf2_Maf ^ Cytosol_nucleus_trans_MRP_1_n - Cytosol_nucleus_trans_MRP_1_kb * Cytosol_nucleus_Nrf2_Maf__EpRE_MRP_;
Cytosol_nucleus_trans_MRP_2 = (Cytosol_nucleus_trans_MRP_2_k0 * Cytosol_nucleus_MRPoff + (Cytosol_nucleus_trans_MRP_2_kf * Cytosol_nucleus_MRPoff) * Cytosol_nucleus_Nrf2_Maf__EpRE_MRP_) - Cytosol_nucleus_trans_MRP_2_kb * Cytosol_nucleus_MRPon;
Cytosol_nucleus_reaction_Nrf2_Maf = (Cytosol_nucleus_reaction_Nrf2_Maf_kf * Cytosol_nucleus_Nrf2) * Cytosol_nucleus_Maf - Cytosol_nucleus_reaction_Nrf2_Maf_kb * Cytosol_nucleus_Nrf2_Maf;
Cytosol_nucleus_trans_GCLC_3_b = 1 / 3;
Cytosol_nucleus_trans_GCLC_3 = ((Cytosol_nucleus_trans_GCLC_3_kf * Cytosol_nucleus_GCLCon) * Cytosol_nucleus_trans_GCLC_3_b) * 1.65;
Cytosol_nucleus_trans_Nrf2_1 = (Cytosol_nucleus_trans_Nrf2_1_kf * Cytosol_nucleus_EpRE_Nrf2_) * Cytosol_nucleus_Nrf2_Maf - Cytosol_nucleus_trans_Nrf2_1_kb * Cytosol_nucleus_Nrf2_Maf__EpRE_Nrf2_;
Cytosol_nucleus_reaction_Nrf2_nuclear_degradation = Cytosol_nucleus_reaction_Nrf2_nuclear_degradation_kf * Cytosol_nucleus_Nrf2;
Cytosol_nucleus_trans_GS_2 = (Cytosol_nucleus_trans_GS_2_k0 * Cytosol_nucleus_GSoff + (Cytosol_nucleus_trans_GS_2_kf * Cytosol_nucleus_GSoff) * Cytosol_nucleus_Nrf2_Maf__EpRE_GS_) - Cytosol_nucleus_trans_GS_2_kb * Cytosol_nucleus_GSon;
Cytosol_nucleus_trans_GCLC_1 = ((Cytosol_nucleus_trans_GCLC_1_k * Cytosol_nucleus_trans_GCLC_1_kf) * Cytosol_nucleus_EpRE_GCLC_) * Cytosol_nucleus_Nrf2_Maf ^ Cytosol_nucleus_trans_GCLC_1_n - Cytosol_nucleus_trans_GCLC_1_kb * Cytosol_nucleus_Nrf2_Maf__EpRE_GCLC_;
Cytosol_nucleus_trans_Nrf2_3_b = 1 / 3;
Cytosol_nucleus_trans_Nrf2_3 = (Cytosol_nucleus_trans_Nrf2_3_kf * Cytosol_nucleus_Nrf2on) * Cytosol_nucleus_trans_Nrf2_3_b;
Cytosol_nucleus_trans_GCLM_1 = ((Cytosol_nucleus_trans_GCLM_1_k * Cytosol_nucleus_trans_GCLM_1_kf) * Cytosol_nucleus_EpRE_GCLM_) * Cytosol_nucleus_Nrf2_Maf ^ Cytosol_nucleus_trans_GCLM_1_n - Cytosol_nucleus_trans_GCLM_1_kb * Cytosol_nucleus_Nrf2_Maf__EpRE_GCLM_;
Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle = Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle_kf * Cytosol_Nrf2 - Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle_kb * Cytosol_nucleus_Nrf2;
Cytosol_nucleus_trans_GCLC_2 = (Cytosol_nucleus_trans_GCLC_2_k0 * Cytosol_nucleus_GCLCoff + (Cytosol_nucleus_trans_GCLC_2_kf * Cytosol_nucleus_GCLCoff) * Cytosol_nucleus_Nrf2_Maf__EpRE_GCLC_) - Cytosol_nucleus_trans_GCLC_2_kb * Cytosol_nucleus_GCLCon;
Cytosol_nucleus_trans_GS_3_b = 1 / 3;
Cytosol_nucleus_trans_GS_3 = (Cytosol_nucleus_trans_GS_3_kf * Cytosol_nucleus_GSon) * Cytosol_nucleus_trans_GS_3_b;
Cytosol_nucleus_trans_GS_1 = ((Cytosol_nucleus_trans_GS_1_k * Cytosol_nucleus_trans_GS_1_kf) * Cytosol_nucleus_EpRE_GS_) * Cytosol_nucleus_Nrf2_Maf ^ Cytosol_nucleus_trans_GS_1_n - Cytosol_nucleus_trans_GS_1_kb * Cytosol_nucleus_Nrf2_Maf__EpRE_GS_;
Cytosol_nucleus_trans_GCLM_3_b = 1 / 3;
Cytosol_nucleus_trans_GCLM_3 = (Cytosol_nucleus_trans_GCLM_3_kf * Cytosol_nucleus_GCLMon) * Cytosol_nucleus_trans_GCLM_3_b;
Cytosol_nucleus_trans_GCLM_2 = (Cytosol_nucleus_trans_GCLM_2_k0 * Cytosol_nucleus_GCLMoff + (Cytosol_nucleus_trans_GCLM_2_kf * Cytosol_nucleus_GCLMoff) * Cytosol_nucleus_Nrf2_Maf__EpRE_GCLM_) - Cytosol_nucleus_trans_GCLM_2_kb * Cytosol_nucleus_GCLMon;
Cytosol_nucleus_trans_Nrf2_2 = (Cytosol_nucleus_trans_Nrf2_2_k0 * Cytosol_nucleus_Nrf2off + (Cytosol_nucleus_trans_Nrf2_2_kf * Cytosol_nucleus_Nrf2off) * Cytosol_nucleus_Nrf2_Maf__EpRE_Nrf2_) - Cytosol_nucleus_trans_Nrf2_2_kb * Cytosol_nucleus_Nrf2on;
Cytosol_trans_Nrf2_5 = Cytosol_trans_Nrf2_5_kf * Cytosol_Nrf2_mRNA;
Cytosol_trans_GS_7 = Cytosol_trans_GS_7_kf * Cytosol_GS;
Cytosol_trans_MRP_5 = Cytosol_trans_MRP_5_kf * Cytosol_MRP_mRNA;
Cytosol_trans_MRP_4 = Cytosol_trans_MRP_4_kf * Cytosol_MRP_mRNA;
Cytosol_trans_MRP_6 = Cytosol_trans_MRP_6_kf * Cytosol_MRPmono;
Cytosol_reaction_MRP_dimerize = (Cytosol_reaction_MRP_dimerize_kf * Cytosol_MRPmono) * Cytosol_MRPmono - Cytosol_reaction_MRP_dimerize_kb * Cytosol_MRP;
Cytosol_trans_MRP_7 = Cytosol_trans_MRP_7_kf * Cytosol_MRP;
Cytosol_reaction_GSH_export = (Cytosol_reaction_GSH_export_Vm * Cytosol_GSH) / (Cytosol_reaction_GSH_export_Km + Cytosol_GSH);
Cytosol_reaction_X_generation_from_stressor = Cytosol_reaction_X_generation_from_stressor_kf * stressor;
Cytosol_reaction_GCL_dimerize = (Cytosol_reaction_GCL_dimerize_kf * Cytosol_GCLM) * Cytosol_GCLC - Cytosol_reaction_GCL_dimerize_kb * Cytosol_GCL;
Cytosol_GSX_export = ((Cytosol_GSX_export_kc * Cytosol_MRP) * Cytosol_GSX) / (Cytosol_GSX_export_Km + Cytosol_GSX);
Cytosol_reaction_Keap1_1 = (Cytosol_reaction_Keap1_1_kf * Cytosol_Nrf2) * Cytosol_Keap1 - Cytosol_reaction_Keap1_1_kb * Cytosol_Nrf2_Keap1;
Cytosol_ATP = 5e6;
Cytosol_trans_GCLC_5 = Cytosol_trans_GCLC_5_kf * Cytosol_GCLC_mRNA;
Cytosol_trans_GCLM_6 = Cytosol_trans_GCLM_6_kf * Cytosol_GCLM;
Cytosol_trans_Nrf2_6 = Cytosol_trans_Nrf2_6_kf * Cytosol_Nrf2;
Cytosol_Cys = 0.3e6;
Cytosol_Glu = 10e6;
Cytosol_enzyme_GCL_r_GCL_Cys = Cytosol_Cys / (Cytosol_enzyme_GCL_Km_GCL_Cys + Cytosol_Cys);
Cytosol_enzyme_GCL_r_GCL_ATP = Cytosol_ATP / (Cytosol_enzyme_GCL_Km_GCL_ATP * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kis_GCL_ATP) + Cytosol_ATP * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kii_GCL_ATP));
Cytosol_enzyme_GCL_r_GCL_Glu = Cytosol_Glu / (Cytosol_enzyme_GCL_Km_GCL_Glu * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kis_GCL_Glu) + Cytosol_Glu * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kii_GCL_Glu));
Cytosol_enzyme_GCL_V_GCLholo = (((Cytosol_enzyme_GCL_kc_GCL * Cytosol_GCL) * Cytosol_enzyme_GCL_r_GCL_Cys) * Cytosol_enzyme_GCL_r_GCL_Glu) * Cytosol_enzyme_GCL_r_GCL_ATP;
Cytosol_enzyme_GCL_r_GCLC_Cys = Cytosol_Cys / (Cytosol_enzyme_GCL_Km_GCLC_Cys + Cytosol_Cys);
Cytosol_enzyme_GCL_r_GCLC_ATP = Cytosol_ATP / (Cytosol_enzyme_GCL_Km_GCLC_ATP * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kis_GCLC_ATP) + Cytosol_ATP * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kii_GCLC_ATP));
Cytosol_enzyme_GCL_r_GCLC_Glu = Cytosol_Glu / (Cytosol_enzyme_GCL_Km_GCLC_Glu * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kis_GCLC_Glu) + Cytosol_Glu * (Cytosol_enzyme_GCL_n + Cytosol_GSH / Cytosol_enzyme_GCL_Kii_GCLC_Glu));
Cytosol_enzyme_GCL_V_GCLC = (((Cytosol_enzyme_GCL_kc_GCLC * Cytosol_GCLC) * Cytosol_enzyme_GCL_r_GCLC_Cys) * Cytosol_enzyme_GCL_r_GCLC_Glu) * Cytosol_enzyme_GCL_r_GCLC_ATP;
Cytosol_enzyme_GCL = Cytosol_enzyme_GCL_V_GCLholo + Cytosol_enzyme_GCL_V_GCLC;
Cytosol_trans_GCLC_6 = Cytosol_trans_GCLC_6_kf * Cytosol_GCLC;
Cytosol_trans_GS_6 = Cytosol_trans_GS_6_kf * Cytosol_GSmono;
Cytosol_reaction_Keap1_6 = (Cytosol_reaction_Keap1_6_kf * Cytosol_Nrf2) * Cytosol_Keap1o - Cytosol_reaction_Keap1_6_kb * Cytosol_Nrf2_Keap1o;
Cytosol_reaction_X_endo_production = Cytosol_reaction_X_endo_production_kf;
Cytosol_trans_GS_4 = Cytosol_trans_GS_4_kf * Cytosol_GS_mRNA;
Cytosol_trans_GCLM_5 = Cytosol_trans_GCLM_5_kf * Cytosol_GCLM_mRNA;
Cytosol_trans_Nrf2_4 = (Cytosol_trans_Nrf2_4_kf * Cytosol_Nrf2_mRNA) * 1;
Cytosol_reaction_Keap1_2 = Cytosol_reaction_Keap1_2_kf * Cytosol_Nrf2_Keap1;
Cytosol_reaction_GCL_degrade = Cytosol_reaction_GCL_degrade_kf * Cytosol_GCL;
Cytosol_reaction_Keap1_3f = Cytosol_Nrf2_Keap1 * (Cytosol_reaction_Keap1_3f_k0 + Cytosol_X * Cytosol_reaction_Keap1_3f_kf_X);
Cytosol_trans_GS_5 = Cytosol_trans_GS_5_kf * Cytosol_GS_mRNA;
Cytosol_trans_GCLC_4 = Cytosol_trans_GCLC_4_kf * Cytosol_GCLC_mRNA;
Cytosol_Gly = 1e6;
Cytosol_reaction_Keap1_3b = Cytosol_reaction_Keap1_3b_kf * Cytosol_Nrf2_Keap1o;
Cytosol_reaction_Keap1_4f = Cytosol_Keap1 * (Cytosol_reaction_Keap1_4f_k0 + Cytosol_X * Cytosol_reaction_Keap1_4f_kf_X);
Cytosol_reaction_Keap1_5 = Cytosol_reaction_Keap1_5_kf * Cytosol_Nrf2_Keap1o;
Cytosol_enzyme_GS_r_rGC = (Cytosol_r_GC / Cytosol_enzyme_GS_Km1_rGC + Cytosol_r_GC ^ 2 / (Cytosol_enzyme_GS_Km1_rGC * Cytosol_enzyme_GS_Km2_rGC)) / ((1 + (2 * Cytosol_r_GC) / Cytosol_enzyme_GS_Km1_rGC) + Cytosol_r_GC ^ 2 / (Cytosol_enzyme_GS_Km1_rGC * Cytosol_enzyme_GS_Km2_rGC));
Cytosol_enzyme_GS_r_Gly = Cytosol_Gly / (Cytosol_enzyme_GS_Km_Gly + Cytosol_Gly);
Cytosol_enzyme_GS_r_ATP = Cytosol_ATP / (Cytosol_enzyme_GS_Km_ATP + Cytosol_ATP);
Cytosol_enzyme_GS = (((Cytosol_enzyme_GS_kc * Cytosol_GS) * Cytosol_enzyme_GS_r_rGC) * Cytosol_enzyme_GS_r_Gly) * Cytosol_enzyme_GS_r_ATP;
Cytosol_trans_GCLM_4 = Cytosol_trans_GCLM_4_kf * Cytosol_GCLM_mRNA;
Cytosol_reaction_Keap1_4b = Cytosol_reaction_Keap1_4b_kf * Cytosol_Keap1o;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DIFFERENTIAL EQUATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
stressor_dot = 0;
Cytosol_GST_mRNA_dot = -Cytosol_trans_GST_4 +Cytosol_nucleus_trans_GST_3*Cytosol_nucleus / Cytosol;
Cytosol_sink_dot = 0;
Cytosol_GSTmono_dot = Cytosol_trans_GST_5 -Cytosol_trans_GST_6 -2 * Cytosol_reaction_GST_dimerize;
Cytosol_Nrf2_mRNA_dot = Cytosol_nucleus_trans_Nrf2_3*Cytosol_nucleus / Cytosol -Cytosol_trans_Nrf2_4;
Cytosol_GST_dot = Cytosol_reaction_GST_dimerize -Cytosol_trans_GST_7;
Cytosol_X_dot = -Cytosol_enzyme_GST +Cytosol_reaction_X_generation_from_stressor +Cytosol_reaction_X_endo_production;
Cytosol_GSH_dot = -Cytosol_enzyme_GST -Cytosol_reaction_GSH_export +Cytosol_enzyme_GS;
Cytosol_GSX_dot = Cytosol_enzyme_GST -Cytosol_GSX_export;
Cytosol_GSmono_dot = -2 * Cytosol_reaction_GS_dimerize -Cytosol_trans_GS_6 +Cytosol_trans_GS_5;
Cytosol_GS_dot = Cytosol_reaction_GS_dimerize -Cytosol_trans_GS_7;
Cytosol_nucleus_GSTon_dot = Cytosol_nucleus_trans_GST_2;
Cytosol_nucleus_EpRE_GST__dot = -Cytosol_nucleus_trans_GST_1;
Cytosol_nucleus_Nrf2_Maf_dot = -2 * Cytosol_nucleus_trans_GST_1 -2 * Cytosol_nucleus_trans_MRP_1 +Cytosol_nucleus_reaction_Nrf2_Maf -Cytosol_nucleus_trans_Nrf2_1 -3 * Cytosol_nucleus_trans_GCLC_1 -3 * Cytosol_nucleus_trans_GCLM_1 -2 * Cytosol_nucleus_trans_GS_1;
Cytosol_nucleus_Nrf2_Maf__EpRE_GST__dot = Cytosol_nucleus_trans_GST_1;
Cytosol_nucleus_GSToff_dot = -Cytosol_nucleus_trans_GST_2;
Cytosol_nucleus_MRPon_dot = Cytosol_nucleus_trans_MRP_2;
Cytosol_MRP_mRNA_dot = Cytosol_nucleus_trans_MRP_3*Cytosol_nucleus / Cytosol -Cytosol_trans_MRP_4;
Cytosol_nucleus_EpRE_MRP__dot = -Cytosol_nucleus_trans_MRP_1;
Cytosol_nucleus_Nrf2_Maf__EpRE_MRP__dot = Cytosol_nucleus_trans_MRP_1;
Cytosol_nucleus_MRPoff_dot = -Cytosol_nucleus_trans_MRP_2;
Cytosol_nucleus_GCLMon_dot = Cytosol_nucleus_trans_GCLM_2;
Cytosol_nucleus_Maf_dot = -Cytosol_nucleus_reaction_Nrf2_Maf;
Cytosol_nucleus_Nrf2_dot = -Cytosol_nucleus_reaction_Nrf2_Maf -Cytosol_nucleus_reaction_Nrf2_nuclear_degradation +Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle / Cytosol_nucleus;
Cytosol_nucleus_EpRE_GCLM__dot = -Cytosol_nucleus_trans_GCLM_1;
Cytosol_nucleus_GSoff_dot = -Cytosol_nucleus_trans_GS_2;
Cytosol_nucleus_GCLCoff_dot = -Cytosol_nucleus_trans_GCLC_2;
Cytosol_nucleus_Nrf2_Maf__EpRE_GCLC__dot = Cytosol_nucleus_trans_GCLC_1;
Cytosol_nucleus_Nrf2_Maf__EpRE_GS__dot = Cytosol_nucleus_trans_GS_1;
Cytosol_nucleus_Nrf2off_dot = -Cytosol_nucleus_trans_Nrf2_2;
Cytosol_nucleus_EpRE_GS__dot = -Cytosol_nucleus_trans_GS_1;
Cytosol_nucleus_GCLCon_dot = Cytosol_nucleus_trans_GCLC_2;
Cytosol_GCLC_mRNA_dot = Cytosol_nucleus_trans_GCLC_3*Cytosol_nucleus / Cytosol -Cytosol_trans_GCLC_4;
Cytosol_nucleus_Nrf2on_dot = Cytosol_nucleus_trans_Nrf2_2;
Cytosol_nucleus_EpRE_Nrf2__dot = -Cytosol_nucleus_trans_Nrf2_1;
Cytosol_nucleus_Nrf2_Maf__EpRE_Nrf2__dot = Cytosol_nucleus_trans_Nrf2_1;
Cytosol_nucleus_sink_dot = 0;
Cytosol_nucleus_GSon_dot = Cytosol_nucleus_trans_GS_2;
Cytosol_nucleus_EpRE_GCLC__dot = -Cytosol_nucleus_trans_GCLC_1;
Cytosol_nucleus_Nrf2_Maf__EpRE_GCLM__dot = Cytosol_nucleus_trans_GCLM_1;
Cytosol_Nrf2_dot = -Cytosol_nucleus_reaction_Nrf2_nuclear_shuffle / Cytosol +Cytosol_trans_Nrf2_5 -Cytosol_reaction_Keap1_1 -Cytosol_trans_Nrf2_6 -Cytosol_reaction_Keap1_6;
Cytosol_GS_mRNA_dot = Cytosol_nucleus_trans_GS_3*Cytosol_nucleus / Cytosol -Cytosol_trans_GS_4;
Cytosol_GCLM_mRNA_dot = Cytosol_nucleus_trans_GCLM_3*Cytosol_nucleus / Cytosol -Cytosol_trans_GCLM_4;
Cytosol_nucleus_GCLMoff_dot = -Cytosol_nucleus_trans_GCLM_2;
Cytosol_GCLC_dot = -Cytosol_reaction_GCL_dimerize +Cytosol_trans_GCLC_5 -Cytosol_trans_GCLC_6;
Cytosol_r_GC_dot = Cytosol_enzyme_GCL -Cytosol_enzyme_GS;
Cytosol_MRPmono_dot = Cytosol_trans_MRP_5 -Cytosol_trans_MRP_6 -2 * Cytosol_reaction_MRP_dimerize;
Cytosol_MRP_dot = Cytosol_reaction_MRP_dimerize -Cytosol_trans_MRP_7;
Cytosol_Keap1_dot = -Cytosol_reaction_Keap1_1 +Cytosol_reaction_Keap1_2 -Cytosol_reaction_Keap1_4f +Cytosol_reaction_Keap1_4b;
Cytosol_GCLM_dot = -Cytosol_reaction_GCL_dimerize -Cytosol_trans_GCLM_6 +Cytosol_trans_GCLM_5;
Cytosol_GCL_dot = Cytosol_reaction_GCL_dimerize -Cytosol_reaction_GCL_degrade;
Cytosol_Nrf2_Keap1_dot = Cytosol_reaction_Keap1_1 -Cytosol_reaction_Keap1_2 -Cytosol_reaction_Keap1_3f +Cytosol_reaction_Keap1_3b;
Cytosol_Keap1o_dot = -Cytosol_reaction_Keap1_6 +Cytosol_reaction_Keap1_4f +Cytosol_reaction_Keap1_5 -Cytosol_reaction_Keap1_4b;
Cytosol_Nrf2_Keap1o_dot = Cytosol_reaction_Keap1_6 +Cytosol_reaction_Keap1_3f -Cytosol_reaction_Keap1_3b -Cytosol_reaction_Keap1_5;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RETURN VALUES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xdot = [
    stressor_dot ; Cytosol_GST_mRNA_dot ; Cytosol_sink_dot ; Cytosol_GSTmono_dot ; Cytosol_Nrf2_mRNA_dot
            Cytosol_GST_dot ; Cytosol_X_dot ; Cytosol_GSH_dot ; Cytosol_GSX_dot ; Cytosol_GSmono_dot
            Cytosol_GS_dot ; Cytosol_nucleus_GSTon_dot ; Cytosol_nucleus_EpRE_GST__dot ; Cytosol_nucleus_Nrf2_Maf_dot ; Cytosol_nucleus_Nrf2_Maf__EpRE_GST__dot
            Cytosol_nucleus_GSToff_dot ; Cytosol_nucleus_MRPon_dot ; Cytosol_MRP_mRNA_dot ; Cytosol_nucleus_EpRE_MRP__dot ; Cytosol_nucleus_Nrf2_Maf__EpRE_MRP__dot
            Cytosol_nucleus_MRPoff_dot ; Cytosol_nucleus_GCLMon_dot ; Cytosol_nucleus_Maf_dot ; Cytosol_nucleus_Nrf2_dot ; Cytosol_nucleus_EpRE_GCLM__dot
            Cytosol_nucleus_GSoff_dot ; Cytosol_nucleus_GCLCoff_dot ; Cytosol_nucleus_Nrf2_Maf__EpRE_GCLC__dot ; Cytosol_nucleus_Nrf2_Maf__EpRE_GS__dot ; Cytosol_nucleus_Nrf2off_dot
            Cytosol_nucleus_EpRE_GS__dot ; Cytosol_nucleus_GCLCon_dot ; Cytosol_GCLC_mRNA_dot ; Cytosol_nucleus_Nrf2on_dot ; Cytosol_nucleus_EpRE_Nrf2__dot
            Cytosol_nucleus_Nrf2_Maf__EpRE_Nrf2__dot ; Cytosol_nucleus_sink_dot ; Cytosol_nucleus_GSon_dot ; Cytosol_nucleus_EpRE_GCLC__dot ; Cytosol_nucleus_Nrf2_Maf__EpRE_GCLM__dot
            Cytosol_Nrf2_dot ; Cytosol_GS_mRNA_dot ; Cytosol_GCLM_mRNA_dot ; Cytosol_nucleus_GCLMoff_dot ; Cytosol_GCLC_dot
            Cytosol_r_GC_dot ; Cytosol_MRPmono_dot ; Cytosol_MRP_dot ; Cytosol_Keap1_dot ; Cytosol_GCLM_dot
            Cytosol_GCL_dot ; Cytosol_Nrf2_Keap1_dot ; Cytosol_Keap1o_dot ; Cytosol_Nrf2_Keap1o_dot
];
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FUNCTIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [x] = piecewisePWL(varargin)
for i=2:2:(nargin)
    if varargin{i}
        x = varargin{i-1};
        return
    end
end
if mod(nargin,2) == 0
    error('No otherwise value');
end
x = varargin{nargin};
return

function [YI] = derinterp1(X,Y,XI)
lx = length(X);
YI = [];
yismatrix = prod(size(Y) > 1);
for i = 1:length(XI),
    ubx = find(X < XI(i));
    if isempty(ubx)
        xi1 = 1;
    else
        xi1 = ubx(end);
        if (xi1 == lx), xi1 = xi1 - 1; end
    end
    xi2 = xi1 + 1;
    if ((xi1 < 0) | (xi2 > lx))
        error('The data abscissae is too small');
    end
    dx = X(xi2) - X(xi1);
    if (yismatrix), 
        dy = Y(xi2,:) - Y(xi1,:);
    else, dy = Y(xi2) - Y(xi1);
    end
    if size(dy,1) > 1,
        YI(i,:) = dy ./ dx;
    else
        YI(i) = dy ./ dx;
    end
end
